# Printer Code Page Settings Instructions

> * Required interfaces: `setChineseModel`, `selectCodePage`, `selectDefaultCodePage`, `setCharSet`
>
> * Interface Descriptions:
>   1. `setChineseModel`: Used to enable or disable the printer's Chinese mode. The printer can only correctly set Chinese encodings, such as GBK or Big5, in Chinese mode. If you want to set a code page within the range of 1–255, you need to disable Chinese mode.
>   2. `selectCodePage`: Used to set the printer's temporary encoding. This setting will be lost after the printer is powered off. [Except for encodings in Chinese mode]
>   3. `selectDefaultCodePage`: Used to set the printer's default code page, which remains effective even after the printer is powered off. [**Recommended**]
>   4. `setCharSet`: Used to set the SDK's encoding. Ensure that this encoding corresponds to the encoding set on the printer to ensure that the data sent by the application can be correctly parsed by the printer. Note: This interface does not support DOS or other standard encodings.

## Encoding Settings Example

### Set Chinese Encoding

```kotlin
printer.setChineseModel(true)
// Simplified Chinese
printer.selectDefaultCodePage(POSConst.CODE_PAGE_SIMPLIFIED_CHINESE)
                .setCharSet("GB18030")

// Traditional Chinese
printer.selectDefaultCodePage(CODE_PAGE_TRADITIONAL_CHINESE)
                .setCharSet("Big5")
```

### Set WPC1252 Encoding

```kotlin
printer.setChineseModel(false)
// Italian, Norwegian, Portuguese, Spanish, Swedish, German, Finnish, Icelandic, French
printer.selectDefaultCodePage(CODE_PAGE_WPC1252)
                .setCharSet("Windows-1252")
```

> [!tip]
>
> Please confirm whether the printer supports other encodings, such as Turkish Windows-1254 and Arabic Windows-1256.